@@ -24,7 +24,7 @@ const uint32_t ELLIPSIS_CODE_POINT = 0x2026;
 static CharBuf*
 S_do_encode(Highlighter *self, CharBuf *text, CharBuf **encode_buf);
 
-/* Place HTML entity encoded version of [text] into [encoded]. */
+// Place HTML entity encoded version of [text] into [encoded]. 
 static CharBuf*
 S_encode_entities(CharBuf *text, CharBuf *encoded);
 
@@ -111,7 +111,7 @@ Highlighter_create_excerpt(Highlighter *self, HitDoc *hit_doc)
         return NULL;
     }
     else if (!ZCB_Get_Size(field_val)) {
-        /* Empty string yields empty string. */
+        // Empty string yields empty string. 
         return CB_new(0);
     }
     else {
@@ -166,13 +166,13 @@ int32_t
 Highlighter_find_best_fragment(Highlighter *self, const CharBuf *field_val,
                                ViewCharBuf *fragment, HeatMap *heat_map)
 {
-    /* Window is 1.66 * excerpt_length, with the loc in the middle. */
+    // Window is 1.66 * excerpt_length, with the loc in the middle. 
     int32_t best_location = S_hottest(heat_map);
 
     if (best_location < (int32_t)self->slop) {
-        /* If the beginning of the string falls within the window centered
-         * around the hottest point in the field, start the fragment at the
-         * beginning. */
+        // If the beginning of the string falls within the window centered
+        // around the hottest point in the field, start the fragment at the
+        // beginning.
         ViewCB_Assign(fragment, (CharBuf*)field_val);
         int32_t top = ViewCB_Trim_Top(fragment);
         ViewCB_Truncate(fragment, self->window_width);
@@ -187,7 +187,7 @@ Highlighter_find_best_fragment(Highlighter *self, const CharBuf *field_val,
         int32_t overrun = self->excerpt_length - chars_left;
 
         if (!overrun) {
-            /* We've found an acceptable window. */
+            // We've found an acceptable window. 
             ViewCB_Assign(fragment, (CharBuf*)field_val);
             ViewCB_Nip(fragment, top);
             top += ViewCB_Trim_Top(fragment);
@@ -195,13 +195,13 @@ Highlighter_find_best_fragment(Highlighter *self, const CharBuf *field_val,
             return top;
         }
         else if (overrun > top) {
-            /* The field is very short, so make the whole field the
-             * "fragment".  */
+            // The field is very short, so make the whole field the
+            // "fragment".
             ViewCB_Assign(fragment, (CharBuf*)field_val);
             return ViewCB_Trim_Top(fragment);
         }
         else {
-            /* The fragment is too close to the end, so slide it back. */
+            // The fragment is too close to the end, so slide it back. 
             top -= overrun;
             ViewCB_Assign(fragment, (CharBuf*)field_val);
             ViewCB_Nip(fragment, top);
@@ -212,9 +212,9 @@ Highlighter_find_best_fragment(Highlighter *self, const CharBuf *field_val,
     }
 }
 
-/* Return true if the window represented by "offset" and "length" overlaps a
- * score span, or if there are no score spans so that no excerpt is measurably
- * superior. */
+// Return true if the window represented by "offset" and "length" overlaps a
+// score span, or if there are no score spans so that no excerpt is measurably
+// superior.
 static bool_t
 S_has_heat(HeatMap *heat_map, int32_t offset, int32_t length)
 {
@@ -252,7 +252,7 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
                    ? (uint32_t)field_len 
                    : (uint32_t)(self->excerpt_length * 0.6666);
 
-    /* Try to find a starting sentence boundary. */
+    // Try to find a starting sentence boundary. 
     const uint32_t num_sentences = VA_Get_Size(sentences);
     if (num_sentences) {
         for (uint32_t i = 0; i < num_sentences; i++) {
@@ -263,9 +263,9 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
                 break;
             }
             else if (candidate >= top) {
-                /* Try to start on the first sentence boundary, but only if
-                 * there's enough relevant material left after it in the
-                 * fragment. */
+                // Try to start on the first sentence boundary, but only if
+                // there's enough relevant material left after it in the
+                // fragment.
                 ZombieCharBuf *temp = ZCB_WRAP(fragment);
                 ZCB_Nip(temp, candidate - top);
                 uint32_t chars_left = ZCB_Truncate(temp, self->excerpt_length);
@@ -280,7 +280,7 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
         }
     }
 
-    /* Try to end on a sentence boundary (but don't try very hard). */
+    // Try to end on a sentence boundary (but don't try very hard). 
     if (num_sentences) {
         ZombieCharBuf *start_trimmed = ZCB_WRAP(fragment);
         ZCB_Nip(start_trimmed, start - top);
@@ -309,7 +309,7 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
                     ZCB_Nip(temp, chars_left);
                     ZCB_Trim_Tail(temp);
                     if (ZCB_Get_Size(temp) == 0) {
-                        /* Short, but ending on a boundary already. */
+                        // Short, but ending on a boundary already. 
                         found_ending_edge = true;
                         end = last_edge;
                         break;
@@ -329,17 +329,17 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
         ZCB_Truncate(temp, this_excerpt_len);
         CB_Mimic(raw_excerpt, (Obj*)temp);
     }
-    /* If not starting on a sentence boundary, prepend an ellipsis. */
+    // If not starting on a sentence boundary, prepend an ellipsis. 
     else {
         ZombieCharBuf *temp = ZCB_WRAP((CharBuf*)field_val);
-        const size_t ELLIPSIS_LEN = 2; /* Unicode ellipsis plus a space. */
+        const size_t ELLIPSIS_LEN = 2; // Unicode ellipsis plus a space. 
         
-        /* If the excerpt is already shorter than the spec'd length, we might
-         * not need to make room. */
+        // If the excerpt is already shorter than the spec'd length, we might
+        // not need to make room.
         this_excerpt_len += ELLIPSIS_LEN;
 
-        /* Move the start back one in case the character right before the
-         * excerpt starts is whitespace. */
+        // Move the start back one in case the character right before the
+        // excerpt starts is whitespace.
         if (start) {
             this_excerpt_len += 1;
             start -= 1;
@@ -353,8 +353,8 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
 
             if (StrHelp_is_whitespace(code_point)) {
                 if (!found_ending_edge) {
-                    /* If we still need room, we'll lop it off the end since
-                     * we don't know a solid end point yet. */
+                    // If we still need room, we'll lop it off the end since
+                    // we don't know a solid end point yet.
                     break;
                 }
                 else if (this_excerpt_len <= (int32_t)self->excerpt_length) {
@@ -370,7 +370,7 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
         start -= ELLIPSIS_LEN;
     }
 
-    /* If excerpt doesn't end on a sentence boundary, tack on an ellipsis. */
+    // If excerpt doesn't end on a sentence boundary, tack on an ellipsis. 
     if (found_ending_edge) {
         CB_Truncate(raw_excerpt, end - start);
     }
@@ -381,7 +381,7 @@ Highlighter_raw_excerpt(Highlighter *self, const CharBuf *field_val,
             if (StrHelp_is_whitespace(code_point)) {
                 CB_Trim_Tail(raw_excerpt);
 
-                /* Strip punctuation that collides with an ellipsis. */
+                // Strip punctuation that collides with an ellipsis. 
                 code_point = CB_Code_Point_From(raw_excerpt, 1);
                 while (code_point == '.' 
                     || code_point == ','
@@ -449,7 +449,7 @@ Highlighter_highlight_excerpt(Highlighter *self, VArray *spans,
         }
     }
 
-    /* Last text, beyond last highlight span. */
+    // Last text, beyond last highlight span. 
     {
         CharBuf *encoded = S_do_encode(self, (CharBuf*)temp, &encode_buf);
         CB_Cat(highlighted, encoded);
@@ -471,7 +471,7 @@ S_close_sentence(VArray *sentences, Span **sentence_ptr, int32_t sentence_end)
 {
     Span *sentence = *sentence_ptr;
     int32_t length = sentence_end - Span_Get_Offset(sentence);
-    const int32_t MIN_SENTENCE_LENGTH = 3; /* e.g. "OK.", but not "2." */
+    const int32_t MIN_SENTENCE_LENGTH = 3; // e.g. "OK.", but not "2." 
     if (length >= MIN_SENTENCE_LENGTH) {
         Span_Set_Length(sentence, length);
         VA_Push(sentences, (Obj*)sentence);
@@ -506,7 +506,7 @@ Highlighter_find_sentences(Highlighter *self, CharBuf *text, int32_t offset,
      * starts based on a sentence end that has just passed by.
      */
     if (offset <= pos) {
-        /* Assume that first non-whitespace character begins a sentence. */
+        // Assume that first non-whitespace character begins a sentence. 
         if (pos < stop && ZCB_Get_Size(fragment) > 0) {
             sentence = S_start_sentence(pos);
         }
@@ -519,37 +519,37 @@ Highlighter_find_sentences(Highlighter *self, CharBuf *text, int32_t offset,
     while (1) {
         uint32_t code_point = ZCB_Code_Point_At(fragment, 0);
         if (!code_point) {
-            /* End of fragment.  If we have a sentence open, close it,
-             * then bail. */
+            // End of fragment.  If we have a sentence open, close it,
+            // then bail.
             if (sentence) S_close_sentence(sentences, &sentence, pos);
             break;
         }
         else if (code_point == '.') {
             uint32_t whitespace_count;
-            pos += ZCB_Nip(fragment, 1); /* advance past "." */
+            pos += ZCB_Nip(fragment, 1); // advance past "." 
 
             if (pos == stop && ZCB_Get_Size(fragment) == 0) {
-                /* Period ending the field string. */
+                // Period ending the field string. 
                 if (sentence) S_close_sentence(sentences, &sentence, pos);
                 break;
             }
             else if (0 != (whitespace_count = ZCB_Trim_Top(fragment))) {
-                /* We've found a period followed by whitespace.  Close out the
-                 * existing sentence, if there is one. */
+                // We've found a period followed by whitespace.  Close out the
+                // existing sentence, if there is one. */
                 if (sentence) S_close_sentence(sentences, &sentence, pos);
 
-                /* Advance past whitespace. */
+                // Advance past whitespace. 
                 pos += whitespace_count;
                 if (pos < stop && ZCB_Get_Size(fragment) > 0) {
-                    /* Not at the end of the string? Then we've found a
-                     * sentence start. */
+                    // Not at the end of the string? Then we've found a
+                    // sentence start.
                     sentence = S_start_sentence(pos);
                 }
             }
 
-            /* We may not have reached the end of the field yet, but it's
-             * entirely possible that our last sentence overlapped the end of
-             * the fragment -- in which case, it's time to bail. */
+            // We may not have reached the end of the field yet, but it's
+            // entirely possible that our last sentence overlapped the end of
+            // the fragment -- in which case, it's time to bail.
             if (pos >= stop) break;
         }
         else {
@@ -587,9 +587,9 @@ S_encode_entities(CharBuf *text, CharBuf *encoded)
 {
     ZombieCharBuf *temp = ZCB_WRAP(text);
     size_t space = 0;
-    const int MAX_ENTITY_BYTES = 9; /* &#dddddd; */
+    const int MAX_ENTITY_BYTES = 9; // &#dddddd; 
 
-    /* Scan first so that we only allocate once. */
+    // Scan first so that we only allocate once. 
     uint32_t code_point;
     while (0 != (code_point = ZCB_Nip_One(temp))) {
         if (   code_point > 127
