@@ -4,11 +4,11 @@
 
 #include <errno.h>
 #include <stdio.h>
-#include <fcntl.h> /* open, POSIX flags */
+#include <fcntl.h> // open, POSIX flags 
 #include <stdarg.h>
 
 #ifdef CHY_HAS_UNISTD_H 
-  #include <unistd.h> /* close */
+  #include <unistd.h> // close 
 #endif
 
 #ifdef CHY_HAS_SYS_MMAN_H
@@ -23,9 +23,9 @@
 #include "KinoSearch/Store/FSFileHandle.h"
 #include "KinoSearch/Store/FileWindow.h"
 
-/* Convert FileHandle flags to POSIX flags. */
+// Convert FileHandle flags to POSIX flags. 
 static INLINE int
-SI_posix_flags(u32_t fh_flags)
+SI_posix_flags(uint32_t fh_flags)
 {
     int posix_flags = 0;
     if (fh_flags & FH_WRITE_ONLY) { posix_flags |= O_WRONLY; }
@@ -43,42 +43,39 @@ SI_posix_flags(u32_t fh_flags)
 
 #define IS_64_BIT (SIZEOF_PTR == 8 ? true : false)
 
-/* Memory map a region of the file with shared (read-only) permissions.  If
- * the requested length is 0, return NULL.  If an error occurs, return NULL
- * and set Err_error.
- */
+// Memory map a region of the file with shared (read-only) permissions.  If
+// the requested length is 0, return NULL.  If an error occurs, return NULL
+// and set Err_error.
 static INLINE void*
-SI_map(FSFileHandle *self, i64_t offset, i64_t len);
+SI_map(FSFileHandle *self, int64_t offset, int64_t len);
 
-/* Release a memory mapped region assigned by SI_map. 
- */
+// Release a memory mapped region assigned by SI_map. 
 static INLINE bool_t
-SI_unmap(FSFileHandle *self, char *ptr, i64_t len);
+SI_unmap(FSFileHandle *self, char *ptr, int64_t len);
 
-/* 32-bit or 64-bit inlined helpers for FSFH_window. */
+// 32-bit or 64-bit inlined helpers for FSFH_window. 
 static INLINE bool_t
-SI_window(FSFileHandle *self, FileWindow *window, i64_t offset, i64_t len);
+SI_window(FSFileHandle *self, FileWindow *window, int64_t offset, int64_t len);
 
-/* Architecture- and OS- specific initialization for a read-only FSFileHandle.
- */
+// Architecture- and OS- specific initialization for a read-only FSFileHandle.
 static INLINE bool_t 
 SI_init_read_only(FSFileHandle *self);
 
-/* Windows-specific routine needed for closing read-only handles. */
+// Windows-specific routine needed for closing read-only handles. 
 #ifdef CHY_HAS_WINDOWS_H
 static INLINE bool_t 
 SI_close_win_handles(FSFileHandle *self);
 #endif
 
 FSFileHandle*
-FSFH_open(const CharBuf *path, u32_t flags) 
+FSFH_open(const CharBuf *path, uint32_t flags) 
 {
     FSFileHandle *self = (FSFileHandle*)VTable_Make_Obj(FSFILEHANDLE);
     return FSFH_do_open(self, path, flags);
 }
 
 FSFileHandle*
-FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags) 
+FSFH_do_open(FSFileHandle *self, const CharBuf *path, uint32_t flags) 
 {
     FH_do_open((FileHandle*)self, path, flags);
     if (!path || !CB_Get_Size(path)) {
@@ -87,7 +84,7 @@ FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags)
         return NULL;
     }
 
-    /* Attempt to open file. */
+    // Attempt to open file. 
     if (flags & FH_WRITE_ONLY) {
         self->fd = open((char*)CB_Get_Ptr8(path), SI_posix_flags(flags), 0666);
         if (self->fd == -1) { 
@@ -101,7 +98,7 @@ FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags)
             self->len = 0;
         }
         else {
-            /* Derive length. */
+            // Derive length. 
             self->len = lseek64(self->fd, I64_C(0), SEEK_END);
             if (self->len == -1) {
                 Err_set_error(Err_new(CB_newf("lseek64 on %o failed: %s", 
@@ -110,7 +107,7 @@ FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags)
                 return NULL;
             }
             else {
-                i64_t check_val = lseek64(self->fd, I64_C(0), SEEK_SET);
+                int64_t check_val = lseek64(self->fd, I64_C(0), SEEK_SET);
                 if (check_val == -1) {
                     Err_set_error(Err_new(CB_newf("lseek64 on %o failed: %s", 
                         self->path, strerror(errno))));
@@ -122,12 +119,12 @@ FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags)
     }
     else if (flags & FH_READ_ONLY) {
         if (SI_init_read_only(self)) {
-            /* On 64-bit systems, map the whole file up-front. */
+            // On 64-bit systems, map the whole file up-front. 
             if (IS_64_BIT && self->len) {
                 self->buf = (char*)SI_map(self, 0, self->len);
                 if (!self->buf) { 
-                    /* An error occurred during SI_map, which has set
-                     * Err_error for us already. */
+                    // An error occurred during SI_map, which has set
+                    // Err_error for us already.
                     DECREF(self);
                     return NULL;
                 }
@@ -152,13 +149,13 @@ FSFH_do_open(FSFileHandle *self, const CharBuf *path, u32_t flags)
 bool_t
 FSFH_close(FSFileHandle *self)
 {
-    /* On 64-bit systems, cancel the whole-file mapping. */
+    // On 64-bit systems, cancel the whole-file mapping. 
     if (IS_64_BIT && (self->flags & FH_READ_ONLY)) {
         if ( !SI_unmap(self, self->buf, self->len) ) { return false; }
         self->buf = NULL;
     }
     
-    /* Close system-specific handles. */
+    // Close system-specific handles. 
     if (self->fd) {
         if (close(self->fd)) {
             Err_set_error(Err_new(CB_newf("Failed to close file: %s", 
@@ -180,19 +177,19 @@ bool_t
 FSFH_write(FSFileHandle *self, const void *data, size_t len) 
 {
     if (len) { 
-        /* Write data, track file length, check for errors. */
-        i64_t check_val = write(self->fd, data, len);
+        // Write data, track file length, check for errors. 
+        int64_t check_val = write(self->fd, data, len);
         self->len += check_val;
         if (check_val != len) {
             if (check_val == -1) {
                 Err_set_error(Err_new(CB_newf(
                     "Error when writing %u64 bytes: %s",
-                    (u64_t)len, strerror(errno))));
+                    (uint64_t)len, strerror(errno))));
             }
             else {
                 Err_set_error(Err_new(CB_newf(
                     "Attempted to write %u64 bytes, but wrote %i64", 
-                    (u64_t)len, check_val)));
+                    (uint64_t)len, check_val)));
             }
             return false;
         }
@@ -201,16 +198,16 @@ FSFH_write(FSFileHandle *self, const void *data, size_t len)
     return true;
 }
 
-i64_t
+int64_t
 FSFH_length(FSFileHandle *self)
 {
     return self->len;
 }
 
 bool_t
-FSFH_window(FSFileHandle *self, FileWindow *window, i64_t offset, i64_t len)
+FSFH_window(FSFileHandle *self, FileWindow *window, int64_t offset, int64_t len)
 {
-    const i64_t end = offset + len;
+    const int64_t end = offset + len;
     if (!(self->flags & FH_READ_ONLY)) {
         Err_set_error(Err_new(CB_newf("Can't read from write-only handle")));
         return false;
@@ -236,7 +233,7 @@ FSFH_window(FSFileHandle *self, FileWindow *window, i64_t offset, i64_t len)
 #if IS_64_BIT
 
 static INLINE bool_t
-SI_window(FSFileHandle *self, FileWindow *window, i64_t offset, i64_t len)
+SI_window(FSFileHandle *self, FileWindow *window, int64_t offset, int64_t len)
 {
 	FileWindow_Set_Window(window, self->buf + offset, offset, len);
 	return true;
@@ -251,9 +248,9 @@ FSFH_release_window(FSFileHandle *self, FileWindow *window)
 }
 
 bool_t
-FSFH_read(FSFileHandle *self, char *dest, i64_t offset, size_t len)
+FSFH_read(FSFileHandle *self, char *dest, int64_t offset, size_t len)
 {
-    const i64_t end = offset + len;
+    const int64_t end = offset + len;
 
     if (self->flags & FH_WRITE_ONLY) {
         Err_set_error(Err_new(CB_newf(
@@ -268,7 +265,7 @@ FSFH_read(FSFileHandle *self, char *dest, i64_t offset, size_t len)
     else if (end > self->len) {
         Err_set_error(Err_new(CB_newf(
             "Tried to read past EOF: offset %i64 + request %u64 > len %i64", 
-            offset, (u64_t)len, self->len)));
+            offset, (uint64_t)len, self->len)));
         return false;
     }
     memcpy(dest, self->buf + offset, len);
@@ -280,18 +277,18 @@ FSFH_read(FSFileHandle *self, char *dest, i64_t offset, size_t len)
 #else
 
 static INLINE bool_t
-SI_window(FSFileHandle *self, FileWindow *window, i64_t offset, i64_t len)
+SI_window(FSFileHandle *self, FileWindow *window, int64_t offset, int64_t len)
 {
-	/* Release the previously mmap'd region, if any. */
+	// Release the previously mmap'd region, if any. 
 	FSFH_release_window(self, window);
 
 	{
-		/* Start map on a page boundary.  Ensure that the window is at
-		 * least wide enough to view all the data spec'd in the original
-		 * request. */
-		const i64_t remainder       = offset % self->page_size;
-		const i64_t adjusted_offset = offset - remainder;
-		const i64_t adjusted_len    = len + remainder;
+		// Start map on a page boundary.  Ensure that the window is at
+		// least wide enough to view all the data spec'd in the original
+		// request.
+		const int64_t remainder       = offset % self->page_size;
+		const int64_t adjusted_offset = offset - remainder;
+		const int64_t adjusted_len    = len + remainder;
 		char *const buf 
 			= (char*)SI_map(self, adjusted_offset, adjusted_len);
 		if (len && buf == NULL) {
@@ -314,7 +311,7 @@ FSFH_release_window(FSFileHandle *self, FileWindow *window)
     return true;
 }
 
-#endif /* IS_64_BIT vs. 32-bit */
+#endif // IS_64_BIT vs. 32-bit 
 
 /********************************* UNIXEN *********************************/
 
@@ -323,7 +320,7 @@ FSFH_release_window(FSFileHandle *self, FileWindow *window)
 static INLINE bool_t 
 SI_init_read_only(FSFileHandle *self)
 {
-    /* Open. */
+    // Open. 
     self->fd = open((char*)CB_Get_Ptr8(self->path), 
         SI_posix_flags(self->flags), 0666);
     if (self->fd == -1) {
@@ -333,7 +330,7 @@ SI_init_read_only(FSFileHandle *self)
         return false;
     }
 
-    /* Derive len. */
+    // Derive len. 
     self->len = lseek64(self->fd, I64_C(0), SEEK_END);
     if (self->len == -1) {
         Err_set_error(Err_new(CB_newf("lseek64 on %o failed: %s", self->path,
@@ -341,7 +338,7 @@ SI_init_read_only(FSFileHandle *self)
         return false;
     }
     else {
-        i64_t check_val = lseek64(self->fd, I64_C(0), SEEK_SET);
+        int64_t check_val = lseek64(self->fd, I64_C(0), SEEK_SET);
         if (check_val == -1) {
             Err_set_error(Err_new(CB_newf("lseek64 on %o failed: %s",
                 self->path, strerror(errno))));
@@ -349,7 +346,7 @@ SI_init_read_only(FSFileHandle *self)
         }
     }
 
-    /* Get system page size. */
+    // Get system page size. 
 #if defined(_SC_PAGESIZE)
     self->page_size = sysconf(_SC_PAGESIZE);
 #elif defined(_SC_PAGE_SIZE)
@@ -362,12 +359,12 @@ SI_init_read_only(FSFileHandle *self)
 }
 
 static INLINE void*
-SI_map(FSFileHandle *self, i64_t offset, i64_t len)
+SI_map(FSFileHandle *self, int64_t offset, int64_t len)
 {
     void *buf = NULL;
 
     if (len) {
-        /* Read-only memory mapping. */
+        // Read-only memory mapping. 
         buf = mmap(NULL, len, PROT_READ, MAP_SHARED, self->fd, offset);
         if (buf == (void*)-1) {
             Err_set_error(Err_new(CB_newf(
@@ -382,7 +379,7 @@ SI_map(FSFileHandle *self, i64_t offset, i64_t len)
 }
 
 static INLINE bool_t
-SI_unmap(FSFileHandle *self, char *buf, i64_t len)
+SI_unmap(FSFileHandle *self, char *buf, int64_t len)
 {
     if (buf != NULL) {
         if (munmap(buf, len)) {
@@ -396,36 +393,36 @@ SI_unmap(FSFileHandle *self, char *buf, i64_t len)
 
 #if !IS_64_BIT
 bool_t
-FSFH_read(FSFileHandle *self, char *dest, i64_t offset, size_t len)
+FSFH_read(FSFileHandle *self, char *dest, int64_t offset, size_t len)
 {
-    i64_t check_val;
+    int64_t check_val;
     
-    /* Sanity check. */
+    // Sanity check. 
     if (offset < 0) {
         Err_set_error(Err_new(CB_newf(
             "Can't read from an offset less than 0 (%i64)", offset)));
         return false;
     }
 
-    /* Read. */
+    // Read. 
     check_val = pread64(self->fd, dest, len, offset);
-    if (check_val != (i64_t)len) {
+    if (check_val != (int64_t)len) {
         if (check_val == -1) {
             Err_set_error(Err_new(CB_newf(
                 "Tried to read %u64 bytes, got %i64: %s",
-                (u64_t)len, check_val, strerror(errno))));
+                (uint64_t)len, check_val, strerror(errno))));
         }
         else {
             Err_set_error(Err_new(CB_newf(
                 "Tried to read %u64 bytes, got %i64", 
-                (u64_t)len, check_val)));
+                (uint64_t)len, check_val)));
         }
         return false;
     }
 
     return true;
 }
-#endif /* !IS_64_BIT */
+#endif // !IS_64_BIT 
 
 /********************************* WINDOWS **********************************/
 
@@ -438,11 +435,11 @@ SI_init_read_only(FSFileHandle *self)
     char *filepath = (char*)CB_Get_Ptr8(self->path);
     SYSTEM_INFO sys_info;
 
-    /* Get system page size. */
+    // Get system page size. 
     GetSystemInfo(&sys_info);
     self->page_size = sys_info.dwAllocationGranularity;
 
-    /* Open. */
+    // Open. 
     self->win_fhandle = CreateFile(
         filepath,
         GENERIC_READ,
@@ -460,7 +457,7 @@ SI_init_read_only(FSFileHandle *self)
         return false;
     }
 
-    /* Derive len. */
+    // Derive len. 
     GetFileSizeEx(self->win_fhandle, &large_int);
     self->len = large_int.QuadPart;
     if (self->len < 0) {
@@ -470,7 +467,7 @@ SI_init_read_only(FSFileHandle *self)
         return false;
     }
 
-    /* Init mapping handle. */
+    // Init mapping handle. 
     self->buf = NULL;
     if (self->len) {
         self->win_maphandle = CreateFileMapping(self->win_fhandle, NULL,
@@ -489,13 +486,13 @@ SI_init_read_only(FSFileHandle *self)
 }
 
 static INLINE void*
-SI_map(FSFileHandle *self, i64_t offset, i64_t len)
+SI_map(FSFileHandle *self, int64_t offset, int64_t len)
 {
     void *buf = NULL;
 
     if (len) {
-        /* Read-only memory map. */
-        u64_t offs = (u64_t)offset;
+        // Read-only memory map. 
+        uint64_t offs = (uint64_t)offset;
         DWORD file_offset_hi = offs >> 32;
         DWORD file_offset_lo = offs & 0xFFFFFFFF;
         size_t amount = (size_t)len;
@@ -519,7 +516,7 @@ SI_map(FSFileHandle *self, i64_t offset, i64_t len)
 }
 
 static INLINE bool_t
-SI_unmap(FSFileHandle *self, char *buf, i64_t len)
+SI_unmap(FSFileHandle *self, char *buf, int64_t len)
 {
     if (buf != NULL) {
         if (!UnmapViewOfFile(buf)) {
@@ -536,7 +533,7 @@ SI_unmap(FSFileHandle *self, char *buf, i64_t len)
 static INLINE bool_t 
 SI_close_win_handles(FSFileHandle *self)
 {
-    /* Close both standard handle and mapping handle. */
+    // Close both standard handle and mapping handle. 
     if (self->win_maphandle) {
         if (!CloseHandle(self->win_maphandle)) {
             char *win_error = Err_win_error();
@@ -563,56 +560,56 @@ SI_close_win_handles(FSFileHandle *self)
 
 #if !IS_64_BIT
 bool_t
-FSFH_read(FSFileHandle *self, char *dest, i64_t offset, size_t len)
+FSFH_read(FSFileHandle *self, char *dest, int64_t offset, size_t len)
 {
     BOOL check_val;
     DWORD got;
     OVERLAPPED read_op_state;
-    u64_t offs = (u64_t)offset;
+    uint64_t offs = (uint64_t)offset;
 
     read_op_state.hEvent     = NULL;
     read_op_state.OffsetHigh = offs >> 32;
     read_op_state.Offset     = offs & 0xFFFFFFFF;
     
-    /* Sanity check. */
+    // Sanity check. 
     if (offset < 0) {
         Err_set_error(Err_new(CB_newf(
             "Can't read from an offset less than 0 (%i64)", offset)));
         return false;
     }
 
-    /* ReadFile() takes a DWORD (unsigned 32-bit integer) as a length
-     * argument, so throw a sensible error rather than wrap around. */
+    // ReadFile() takes a DWORD (unsigned 32-bit integer) as a length
+    // argument, so throw a sensible error rather than wrap around. 
     if (len > U32_MAX) {
         Err_set_error(Err_new(CB_newf(
-            "Can't read more than 4 GB (%u64)", (u64_t)len))); 
+            "Can't read more than 4 GB (%u64)", (uint64_t)len))); 
         return false;
     }
 
-    /* Read. */
+    // Read. 
     check_val = ReadFile(self->win_fhandle, dest, len, &got, &read_op_state);
     if (!check_val && GetLastError() == ERROR_IO_PENDING) {
-        /* Read has been queued by the OS and will soon complete.  Wait for
-         * it, since this is a blocking IO call from the point of the rest of
-         * the library. */
+        // Read has been queued by the OS and will soon complete.  Wait for
+        // it, since this is a blocking IO call from the point of the rest of
+        // the library.
         check_val = GetOverlappedResult(self->win_fhandle, &read_op_state,
            &got, TRUE);
     }
 
-    /* Verify that the read has succeeded by now. */
+    // Verify that the read has succeeded by now. 
     if (!check_val) {
         char *win_error = Err_win_error();
         Err_set_error(Err_new(CB_newf("Failed to read %u64 bytes: %s",
-            (u64_t)len, win_error)));
+            (uint64_t)len, win_error)));
         FREEMEM(win_error);
         return false;
     }
 
     return true;
 }
-#endif /* !IS_64_BIT */
+#endif // !IS_64_BIT 
 
-#endif /* CHY_HAS_SYS_MMAN_H vs. CHY_HAS_WINDOWS_H */
+#endif // CHY_HAS_SYS_MMAN_H vs. CHY_HAS_WINDOWS_H 
 
 /* Copyright 2006-2010 Marvin Humphrey
  *
