@@ -8,23 +8,23 @@
 #include "KinoSearch/Search/SeriesMatcher.h"
 
 static SeriesMatcher*
-S_make_series_matcher(I32Array *doc_ids, I32Array *offsets, i32_t doc_max)
+S_make_series_matcher(I32Array *doc_ids, I32Array *offsets, int32_t doc_max)
 {
-    i32_t    num_doc_ids  = I32Arr_Get_Size(doc_ids);
-    i32_t    num_matchers = I32Arr_Get_Size(offsets);
+    int32_t  num_doc_ids  = I32Arr_Get_Size(doc_ids);
+    int32_t  num_matchers = I32Arr_Get_Size(offsets);
     VArray  *matchers     = VA_new(num_matchers);
-    i32_t    tick         = 0;
-    i32_t    i;
+    int32_t  tick         = 0;
+    int32_t  i;
 
-    /* Divvy up doc_ids by segment into BitVectors. */
+    // Divvy up doc_ids by segment into BitVectors. 
     for (i = 0; i < num_matchers; i++) {
-        i32_t offset = I32Arr_Get(offsets, i);
-        i32_t max    = i == num_matchers - 1
-                     ? doc_max + 1
-                     : I32Arr_Get(offsets, i + 1);
+        int32_t offset = I32Arr_Get(offsets, i);
+        int32_t max    = i == num_matchers - 1
+                       ? doc_max + 1
+                       : I32Arr_Get(offsets, i + 1);
         BitVector *bit_vec = BitVec_new(max - offset);
         while (tick < num_doc_ids) {
-            i32_t doc_id = I32Arr_Get(doc_ids, tick);
+            int32_t doc_id = I32Arr_Get(doc_ids, tick);
             if (doc_id > max) { break; }
             else               { tick++; }
             BitVec_Set(bit_vec, doc_id - offset);
@@ -41,12 +41,12 @@ S_make_series_matcher(I32Array *doc_ids, I32Array *offsets, i32_t doc_max)
 }
 
 static I32Array*
-S_generate_match_list(i32_t first, i32_t max, i32_t doc_inc) 
+S_generate_match_list(int32_t first, int32_t max, int32_t doc_inc) 
 {
-    i32_t  count     = (i32_t)ceil(((float)max - first) / doc_inc);
-    i32_t *doc_ids   = (i32_t*)MALLOCATE(count * sizeof(i32_t));
-    i32_t  doc_id    = first;
-    i32_t  i         = 0; 
+    int32_t  count     = (int32_t)ceil(((float)max - first) / doc_inc);
+    int32_t *doc_ids   = (int32_t*)MALLOCATE(count * sizeof(int32_t));
+    int32_t  doc_id    = first;
+    int32_t  i         = 0; 
 
     for ( ; doc_id < max; doc_id += doc_inc, i++) {
         doc_ids[i] = doc_id;
@@ -57,8 +57,8 @@ S_generate_match_list(i32_t first, i32_t max, i32_t doc_inc)
 }
 
 static void
-S_do_test_matrix(TestBatch *batch, i32_t doc_max, i32_t first_doc_id, 
-               i32_t doc_inc, i32_t offset_inc) 
+S_do_test_matrix(TestBatch *batch, int32_t doc_max, int32_t first_doc_id, 
+               int32_t doc_inc, int32_t offset_inc) 
 {
     I32Array *doc_ids 
         = S_generate_match_list(first_doc_id, doc_max, doc_inc);
@@ -66,8 +66,8 @@ S_do_test_matrix(TestBatch *batch, i32_t doc_max, i32_t first_doc_id,
         = S_generate_match_list(0, doc_max, offset_inc);
     SeriesMatcher *series_matcher
         = S_make_series_matcher(doc_ids, offsets, doc_max);
-    u32_t num_in_agreement = 0;
-    i32_t got;
+    uint32_t num_in_agreement = 0;
+    int32_t got;
 
     while (0 != (got = SeriesMatcher_Next(series_matcher))) {
         if (got != I32Arr_Get(doc_ids, num_in_agreement)) { break; }
@@ -85,20 +85,20 @@ S_do_test_matrix(TestBatch *batch, i32_t doc_max, i32_t first_doc_id,
 static void
 test_matrix(TestBatch *batch)
 {
-    i32_t doc_max_nums[]    = { 10, 100, 1000, 0 };
-    i32_t first_doc_ids[]   = { 1, 2, 10, 0 };
-    i32_t doc_inc_nums[]     = { 20, 13, 9, 4, 2, 0 };
-    i32_t offset_inc_nums[]  = { 7, 29, 71, 0 };
-    i32_t a, b, c, d;
+    int32_t doc_max_nums[]    = { 10, 100, 1000, 0 };
+    int32_t first_doc_ids[]   = { 1, 2, 10, 0 };
+    int32_t doc_inc_nums[]     = { 20, 13, 9, 4, 2, 0 };
+    int32_t offset_inc_nums[]  = { 7, 29, 71, 0 };
+    int32_t a, b, c, d;
 
     for (a = 0; doc_max_nums[a] != 0; a++) {
         for (b = 0; first_doc_ids[b] != 0; b++) {
             for (c = 0; doc_inc_nums[c] != 0; c++) {
                 for(d = 0; offset_inc_nums[d] != 0; d++) {
-                    i32_t doc_max        = doc_max_nums[a];
-                    i32_t first_doc_id   = first_doc_ids[b];
-                    i32_t doc_inc        = doc_inc_nums[c];
-                    i32_t offset_inc     = offset_inc_nums[d];
+                    int32_t doc_max        = doc_max_nums[a];
+                    int32_t first_doc_id   = first_doc_ids[b];
+                    int32_t doc_inc        = doc_inc_nums[c];
+                    int32_t offset_inc     = offset_inc_nums[d];
                     if (first_doc_id > doc_max) { 
                         continue; 
                     }
