@@ -258,7 +258,7 @@ test_Rename(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     OutStream_Close(outstream);
     DECREF(outstream);
 
-    /* Move files. */
+    // Move files. 
 
     result = Folder_Rename(folder, &boffo, &banana); 
     ASSERT_TRUE(batch, result, "Rename succeeds and returns true");
@@ -301,7 +301,7 @@ test_Rename(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
         Folder_Delete(folder, &boffo);
     }
 
-    /* Move Dirs. */
+    // Move Dirs. 
 
     Folder_MkDir(folder, &baz);
     result = Folder_Rename(folder, &baz, &boffo); 
@@ -325,7 +325,7 @@ test_Rename(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     ASSERT_FALSE(batch, Folder_Exists(folder, &foo_foo), 
         "Folder no longer exists at old path");
     
-    /* Test failed clobbers. */
+    // Test failed clobbers. 
 
     Err_set_error(NULL);
     result = Folder_Rename(folder, &foo_boffo, &foo_bar); 
@@ -347,7 +347,7 @@ test_Rename(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     ASSERT_TRUE(batch, Folder_Exists(folder, &foo_boffo), 
         "File still exists after failed clobber");
 
-    /* Test that "renaming" succeeds where to and from are the same. */
+    // Test that "renaming" succeeds where to and from are the same. 
 
     result = Folder_Rename(folder, &foo_boffo, &foo_boffo); 
     ASSERT_TRUE(batch, result, "Renaming file to itself succeeds");
@@ -359,7 +359,7 @@ test_Rename(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     ASSERT_TRUE(batch, Folder_Exists(folder, &foo_bar), 
         "Dir still exists");
 
-    /* Invalid filepaths. */
+    // Invalid filepaths. 
 
     Err_set_error(NULL);
     result = Folder_Rename(folder, &foo_boffo, &nope_nyet); 
@@ -395,7 +395,7 @@ test_Hard_Link(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     outstream = Folder_Open_Out(folder, &boffo);
     DECREF(outstream);
 
-    /* Link files. */
+    // Link files. 
 
     result = Folder_Hard_Link(folder, &boffo, &banana); 
     ASSERT_TRUE(batch, result, "Hard_Link succeeds and returns true");
@@ -421,7 +421,7 @@ test_Hard_Link(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
         "File still exists at old path");
     Folder_Delete(folder, &foo_bar_boffo);
 
-    /* Invalid clobbers. */
+    // Invalid clobbers. 
 
     outstream = Folder_Open_Out(folder, &boffo);
     DECREF(outstream);
@@ -442,7 +442,7 @@ test_Hard_Link(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
         "File still exists at old path");
     Folder_Delete(folder, &baz);
 
-    /* Invalid Hard_Link of dir. */
+    // Invalid Hard_Link of dir. 
 
     Folder_MkDir(folder, &baz);
     result = Folder_Hard_Link(folder, &baz, &banana); 
@@ -453,14 +453,14 @@ test_Hard_Link(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
         "Folder still exists at old path");
     Folder_Delete(folder, &baz);
 
-    /* Test that linking to yourself fails. */
+    // Test that linking to yourself fails. 
 
     result = Folder_Hard_Link(folder, &foo_boffo, &foo_boffo); 
     ASSERT_FALSE(batch, result, "Hard_Link file to itself fails");
     ASSERT_TRUE(batch, Folder_Exists(folder, &foo_boffo), 
         "File still exists");
 
-    /* Invalid filepaths. */
+    // Invalid filepaths. 
 
     Err_set_error(NULL);
     result = Folder_Rename(folder, &foo_boffo, &nope_nyet); 
@@ -496,7 +496,7 @@ test_Close(TestBatch *batch, set_up_t set_up, tear_down_t tear_down)
     tear_down();
 }
 
-u32_t
+uint32_t
 TestFolderCommon_num_tests()
 {
     return 99;
