@@ -14,6 +14,22 @@
 #include "KinoSearch/Store/RAMFileHandle.h"
 #include "KinoSearch/Util/NumberUtils.h"
 
+static void
+test_Align(TestBatch *batch)
+{
+    RAMFile    *file      = RAMFile_new(NULL, false);
+    OutStream  *outstream = OutStream_open((Obj*)file);
+
+    for (int32_t i = 1; i < 32; i++) {
+        int64_t random_bytes = TestUtils_random_u64() % 32;
+        while (random_bytes--) { OutStream_Write_U8(outstream, 0); }
+        ASSERT_TRUE(batch, (OutStream_Align(outstream, i) % i) == 0,
+            "Align to %ld", (long)i);
+    }
+    DECREF(file);
+    DECREF(outstream);
+}
+
 static void
 test_Read_Write_Bytes(TestBatch *batch)
 {
@@ -41,7 +57,7 @@ test_Buf(TestBatch *batch)
     OutStream  *outstream = OutStream_open((Obj*)file);
     InStream   *instream;
     size_t      size = IO_STREAM_BUF_SIZE * 2 + 5;
-    u32_t i;
+    uint32_t i;
     char       *buf;
 
     for (i = 0; i < size; i++) {
@@ -54,7 +70,7 @@ test_Buf(TestBatch *batch)
     ASSERT_INT_EQ(batch, instream->limit - buf, IO_STREAM_BUF_SIZE, 
         "Small request bumped up");
 
-    buf += IO_STREAM_BUF_SIZE - 10; /* 10 bytes left in buffer. */
+    buf += IO_STREAM_BUF_SIZE - 10; // 10 bytes left in buffer. 
     InStream_Advance_Buf(instream, buf);
 
     buf = InStream_Buf(instream, 10);
@@ -66,9 +82,9 @@ test_Buf(TestBatch *batch)
         "Requesting over limit triggers refill");
 
     {
-        i64_t  expected = InStream_Length(instream) - InStream_Tell(instream);
-        char  *buff     = InStream_Buf(instream, 100000); 
-        i64_t  got      = PTR2I64(instream->limit) - PTR2I64(buff);
+        int64_t  expected = InStream_Length(instream) - InStream_Tell(instream);
+        char    *buff     = InStream_Buf(instream, 100000); 
+        int64_t  got      = PTR2I64(instream->limit) - PTR2I64(buff);
         ASSERT_TRUE(batch, got == expected,
             "Requests greater than file size get pared down");
     }
@@ -81,11 +97,12 @@ test_Buf(TestBatch *batch)
 void
 TestIOChunks_run_tests()
 {
-    TestBatch   *batch     = TestBatch_new(5);
+    TestBatch *batch = TestBatch_new(36);
 
     srand((unsigned int)time((time_t*)NULL));
     TestBatch_Plan(batch);
 
+    test_Align(batch);
     test_Read_Write_Bytes(batch);
     test_Buf(batch);
     
