@@ -6,10 +6,9 @@
 static void
 S_init_arena(MemoryPool *self, size_t amount);
 
-#define DEFAULT_BUF_SIZE 0x100000 /* 1 MiB */
+#define DEFAULT_BUF_SIZE 0x100000 // 1 MiB 
 
-/* Enlarge amount so pointers will always be aligned.
- */
+// Enlarge amount so pointers will always be aligned.
 #define INCREASE_TO_WORD_MULTIPLE(_amount) \
     do { \
         const size_t _remainder = _amount % sizeof(void*); \
@@ -20,10 +19,15 @@ S_init_arena(MemoryPool *self, size_t amount);
     } while (0)
 
 MemoryPool*
-MemPool_new(u32_t arena_size)
+MemPool_new(uint32_t arena_size)
 {
     MemoryPool *self = (MemoryPool*)VTable_Make_Obj(MEMORYPOOL);
+    return MemPool_init(self, arena_size);
+}
 
+MemoryPool*
+MemPool_init(MemoryPool *self, uint32_t arena_size)
+{
     self->arena_size = arena_size == 0 ? DEFAULT_BUF_SIZE : arena_size;
     self->arenas     = VA_new(16);
     self->tick       = -1;
@@ -45,13 +49,13 @@ static void
 S_init_arena(MemoryPool *self, size_t amount)
 {
     ByteBuf *bb;
-    i32_t i;
+    int32_t i;
 
-    /* Indicate which arena we're using at present. */
+    // Indicate which arena we're using at present. 
     self->tick++;
 
-    if (self->tick < (i32_t)VA_Get_Size(self->arenas)) {
-        /* In recycle mode, use previously acquired memory. */
+    if (self->tick < (int32_t)VA_Get_Size(self->arenas)) {
+        // In recycle mode, use previously acquired memory. 
         bb = (ByteBuf*)VA_Fetch(self->arenas, self->tick);
         if (amount >= BB_Get_Size(bb)) {
             BB_Grow(bb, amount);
@@ -59,7 +63,7 @@ S_init_arena(MemoryPool *self, size_t amount)
         }
     }
     else {
-        /* In add mode, get more mem from system. */
+        // In add mode, get more mem from system. 
         size_t buf_size = (amount + 1) > self->arena_size 
             ? (amount + 1)
             : self->arena_size;
@@ -70,7 +74,7 @@ S_init_arena(MemoryPool *self, size_t amount)
         VA_Push(self->arenas, (Obj*)bb);
     }
 
-    /* Recalculate consumption to take into account blocked off space. */
+    // Recalculate consumption to take into account blocked off space. 
     self->consumed = 0;
     for (i = 0; i < self->tick; i++) {
         ByteBuf *bb = (ByteBuf*)VA_Fetch(self->arenas, i);
@@ -90,16 +94,16 @@ MemPool_grab(MemoryPool *self, size_t amount)
     INCREASE_TO_WORD_MULTIPLE(amount);
     self->last_buf = self->buf;
 
-    /* Verify that we have enough stocked up, otherwise get more. */
+    // Verify that we have enough stocked up, otherwise get more. 
     self->buf += amount;
     if (self->buf >= self->limit) {
-        /* Get enough mem from system or die trying. */
+        // Get enough mem from system or die trying. 
         S_init_arena(self, amount);
         self->last_buf = self->buf;
         self->buf += amount;
     }
 
-    /* Track bytes we've allocated from this pool. */
+    // Track bytes we've allocated from this pool. 
     self->consumed += amount;
 
     return self->last_buf;
@@ -122,7 +126,7 @@ MemPool_resize(MemoryPool *self, void *ptr, size_t new_amount)
         }
         else {
             THROW(ERR, "Can't resize to greater amount: %u64 > %u64", 
-                (u64_t)new_amount, (u64_t)last_amount);
+                (uint64_t)new_amount, (uint64_t)last_amount);
         }
     }
 }
@@ -138,14 +142,14 @@ MemPool_release_all(MemoryPool *self)
 
 void
 MemPool_eat(MemoryPool *self, MemoryPool *other) {
-    i32_t i;
+    int32_t i;
     if (self->buf != NULL)
         THROW(ERR, "Memory pool is not empty");
 
-    /* Move active arenas from other to self. */
+    // Move active arenas from other to self. 
     for (i = 0; i <= other->tick; i++) {
         ByteBuf *arena = (ByteBuf*)VA_Shift(other->arenas);
-        /* Maybe displace existing arena. */
+        // Maybe displace existing arena. 
         VA_Store(self->arenas, i, (Obj*)arena); 
     }
     self->tick     = other->tick;
