@@ -1,3 +1,4 @@
+package KinoSearch::Index::DeletionsWriter;
 use KinoSearch;
 
 1;
@@ -15,7 +16,7 @@ my $synopsis = <<'END_SYNOPSIS';
     }
 END_SYNOPSIS
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel       => "KinoSearch",
     class_name   => "KinoSearch::Index::DeletionsWriter",
     bind_methods => [
@@ -41,7 +42,7 @@ Boilerplater::Binding::Perl::Class->register(
         ],
     },
 );
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Index::DefaultDeletionsWriter",
     bind_constructors => ["new"],
@@ -49,7 +50,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
